@@ -41,13 +41,6 @@ class QLDBDriver:
         statement = f"DROP TABLE {table_name}"
         self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
-        while True:
-            sleep(self.TABLE_DELETION_POLL_PERIOD_SEC)
-
-            if not self.table_exists(table_name):
-                break
-
-
 
     def table_exists(self, table_name):
         return table_name in self.list_tables()
